Additional resources
====================

- `Nengo documentation <https://pythonhosted.org/nengo/>`_: If you are new to
  Nengo, you should start here.

- `TensorFlow documentation <https://www.tensorflow.org/>`_: Knowledge of
  TensorFlow is not required to use NengoDL.  However, some familiarity will
  help take advantage of the advanced NengoDL features.

- :doc:`NengoDL developer documentation <backend>`: If you want
  to know more about how things are working under the hood.